lang_tr_generator library

A library for generating and managing language translations.

Classes

LangTrGenerator
A class responsible for generating language translation methods.

Functions

printError(String text) → void
Prints text to the console as an error message with red color.
printSuccess(String text) → void
Prints text to the console as a success message with green color.
printText(String text) → void
Prints text to the console.
printWarning(String text) → void
Prints text to the console as a warning message with yellow color.